GOAPI class abstract

Implementers

Constructors

GOAPI()

Properties

baseUrl String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alert(Response response) Future<void>
delete(String path) GOAPICommand
get(String path) GOAPICommand
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path) GOAPICommand
post(String path) GOAPICommand
put(String path) GOAPICommand
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited