GOAPICommand class abstract

Implementers

Constructors

GOAPICommand()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

body(Object body) GOAPICommand
json(Object body) GOAPICommand
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(String key, String? value) GOAPICommand
request() Future<Response>
toString() String
A string representation of this object.
inherited
use(GOAPIMiddleware middleware) GOAPICommand
useAuth() GOAPICommand

Operators

operator ==(Object other) bool
The equality operator.
inherited