GODefaultAPI class

Implemented types

Constructors

GODefaultAPI({required String baseUrl})

Properties

baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alert(Response response) Future<void>
override
delete(String path) GOAPICommand
override
endpoint(String path) Uri
get(String path) GOAPICommand
override
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path) GOAPICommand
override
post(String path) GOAPICommand
override
put(String path) GOAPICommand
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited