GODefaultSecureStorage class

Implemented types

Constructors

GODefaultSecureStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findAccessToken() String?
override
findRefreshToken() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String key) Future<String?>
override
saveAccessToken(String? token) → void
override
saveRefreshToken(String? token) Future<void>
override
toString() String
A string representation of this object.
inherited
write(String key, String value) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited