GO class

Constructors

GO()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

api GOAPI
no setter
channel GOChannel
no setter
context BuildContext
no setter
debugMode bool
getter/setter pair
no setter
final
secureStorage GOSecureStorage
no setter

Static Methods

alert({required String title, required String message}) Future<void>
confirm({String title = "확인", required String message}) Future<bool>
dispatch(dynamic event) → dynamic
of<T>(BuildContext context) → T
require<T>() → T
requireOrNull<T>() → T?
trace(Object? object) → dynamic