GOSecureStorage class abstract

Implementers

Constructors

GOSecureStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

findAccessToken() String?
findRefreshToken() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String key) Future<String?>
saveAccessToken(String? token) → void
saveRefreshToken(String? token) Future<void>
toString() String
A string representation of this object.
inherited
write(String key, String value) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited