GONavigator class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
goTo<
T> (Widget widget, {bool? immediate}) → Future< T?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pop<
T> ([T? result]) → void -
removeTo<
T> (Widget widget, {bool? immediate}) → Future< T?> -
replaceTo<
T, TO> (Widget widget, {bool? immediate}) → Future< T?> -
route<
T> (Widget widget, {bool? immediate}) → Route< T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited